abacusai.drift_distributions — AbacusAI documentation

# abacusai.drift_distributions

## Classes

`DriftDistribution` | How actuals or predicted values have changed in the training data versus predicted data
`AbstractApiClass` |
`DriftDistributions` | For either actuals or predicted values, how it has changed in the training data versus some specified window

## Module Contents

class abacusai.drift_distributions.DriftDistribution(client, trainColumn=None, predictedColumn=None, metrics=None, distribution={})

  Bases: `abacusai.return_class.AbstractApiClass`

  How actuals or predicted values have changed in the training data versus predicted data

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - trainColumn (str) – The feature name in the train table.

    - predictedColumn (str) – The feature name in the prediction table.

    - metrics (dict) – Drift measures.

    - distribution (FeatureDistribution) – A FeatureDistribution, how the training data compares to the predicted data.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

class abacusai.drift_distributions.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.drift_distributions.DriftDistributions(client, labelDrift={}, predictionDrift={}, bpPredictionDrift={})

  Bases: `abacusai.return_class.AbstractApiClass`

  For either actuals or predicted values, how it has changed in the training data versus some specified window

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - labelDrift (DriftDistribution) – A DriftDistribution describing column names and the range of values for label drift.

    - predictionDrift (DriftDistribution) – A DriftDistribution describing column names and the range of values for prediction drift.

    - bpPredictionDrift (DriftDistribution) – A DriftDistribution describing column names and the range of values for prediction drift, when the predictions come from BP.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict